use actix_session::{storage::RedisSessionStore, SessionMiddleware};
use actix_web::{cookie::Key, middleware::Logger, web, App, HttpResponse, HttpServer};

mod controller;

#[actix_web::main]
async fn main() -> std::io::Result<()> {
    env_logger::init_from_env(env_logger::Env::new().default_filter_or("info"));

    let redis_conn = connect_to_redis_database().await;

    HttpServer::new(move || {
        App::new()
            .wrap(Logger::default())
            .wrap(SessionMiddleware::new(
                redis_conn.clone(),
                // use dotenvy here to get SECRET_KEY (if we want to have the same on every startup)
                Key::generate(),
            ))
            .configure(controller::register_controllers)
    })
    .bind(("0.0.0.0", 8080))?
    .run()
    .await
}

async fn connect_to_redis_database() -> RedisSessionStore {
    // Build the redis Connection from the .env file Variables
    let redis_connection_string = "redis://127.0.0.1:6379";
    let store = RedisSessionStore::new(redis_connection_string)
        .await
        .unwrap();

    return store;
}
